<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ka">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color</source>
        <translation>დააწკაპუნეთ ფერის შესაცვლელად</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>ფერი</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="178"/>
        <source>GTK themes</source>
        <translation>GTK-ის თემები</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="179"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos;-ს თავზე გადაეწერა.&lt;/p&gt;&lt;p&gt;ძველი პარამეტრების ასლი შეგიძლიათ იპოვოთ აქ: &apos;%2&apos;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error</source>
        <translation>შეცდომა</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error: gsettings cannot be run</source>
        <translation>შეცდომა: gsettings-ის გაშვება შეუძლებელია</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>ფონტი</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>ნაგულისხმევი ფონტი მომხმარებლის ინტერფეისისთვის</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>ფონტის სახელი:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>სტილი:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="77"/>
        <source>Point size:</source>
        <translation>წერტილის ზომა:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="54"/>
        <source>Normal</source>
        <translation>ნორმალური</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="59"/>
        <source>Bold</source>
        <translation>გასქელება</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="64"/>
        <source>Italic</source>
        <translation>დახრა</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="69"/>
        <source>Bold Italic</source>
        <translation>დახრილი მუქი</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>ეს პარამეტრები, მხოლოდ, ახლად გაშვებულ აპლიკაციებს შეეხება</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>მოგლუვებული ფონტების გამოყენება</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="153"/>
        <source>Font hinting style:</source>
        <translation>ფონტის ჰინტინგის სტილი:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="211"/>
        <source>Monospace:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="164"/>
        <source>None</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="169"/>
        <source>Slight</source>
        <translation>ოდნავ</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="174"/>
        <source>Medium</source>
        <translation>საშუალო</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="179"/>
        <source>Full</source>
        <translation>სრული</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="146"/>
        <source>Font hinting</source>
        <translation>ფონტის ჰინტინგი</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="187"/>
        <source>Resolution (DPI):</source>
        <translation>გაფართოება (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="204"/>
        <source>Autohint</source>
        <translation>ავტოჰინტინგი</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Subpixel antialiasing:</source>
        <translation>ქვეპიქსელის მოგლუვება:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="138"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="56"/>
        <source>GTK Style</source>
        <translation>GTK-ის სტილი</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="75"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>GTK-ის თემის დაყენება (GTK-ის კონფიგურაციის ფაილები შეიცვლება!)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="105"/>
        <source>GTK 3 Theme:</source>
        <translation>GTK 3-ის თემა:</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="89"/>
        <source>GTK 2 Theme:</source>
        <translation>GTK 2-ის თემა:</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="117"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>იმისათვის, რომ თემები ერთგვაროვანი იყოს, აირჩიეთ მსგავსი სტილი/თემა (თუ ხელმისაწვდომია) ყველა სიაში, ან აირჩიეთ Qt-ის სტილი &apos;gtk2&apos;, რომ GTK-ი თემის მსგავსად მოვიქცე.

დარწმუნდით, რომ პროგრამა &apos;xsettingsd&apos; დაყენებულია, რომ GTK-ის აპლიკაციის თემები გაშვებულობის დროსაც კი შეიცვალოს.</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt-ის გარეგნობის მორგება</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>ხატულების თემა</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>KDE-ის გაფართოება XDG-ის ხატულის თემებისთვის -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>ხატულების გაფერადება ვიჯეტის სტილის მიხედვით (პალიტრა)</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt-ის თემა</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Use wallpaper provided by theme</source>
        <translation>თემის მოწოდებული ფონის სურათის გამოყენება</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="64"/>
        <source>Use palette provided by theme</source>
        <translation>თემის მოწოდებული პალიტრის გამოყენება</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="83"/>
        <source>(User Theme)</source>
        <translation>(მომხმარებლის თემა)</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="188"/>
        <source>Open theme folder</source>
        <translation>თემების საქაღალდის გახსნა</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>პალიტრები</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>გაფილტვრა...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>&amp;წაშლა</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt-ის გარეგნობის მორგება</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Widget Style</source>
        <translation>ვიჯეტის სტილი</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>Icons Theme</source>
        <translation>ხატულების თემა</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="92"/>
        <source>LXQt Theme</source>
        <translation>LXQt-ის თემა</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Font</source>
        <translation>ფონტი</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>Cursor</source>
        <translation>კურსორი</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>GTK Style</source>
        <translation>GTK-ის სტილი</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="45"/>
        <source>Widget Style</source>
        <translation>ვიჯეტის სტილი</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="75"/>
        <source>Qt Palette</source>
        <translation>Qt-ის პალიტრა</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="89"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>ზოგიერთმა Qt-ის სტილმა, შეიძლება, ეს ფერები გამოტოვოს.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="114"/>
        <source>Window:</source>
        <translation>ფანჯარა:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="124"/>
        <source>View:</source>
        <translation>ხედი:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="134"/>
        <source>Selection:</source>
        <translation>არჩევანი:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="144"/>
        <source>Tooltip:</source>
        <translation>მინიშნება:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="158"/>
        <source>Link:</source>
        <translation>ბმული:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="178"/>
        <source>Window Text:</source>
        <translation>ფანჯრის ტექსტი:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="188"/>
        <source>View Text:</source>
        <translation>ტექსტის ნახვა:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="198"/>
        <source>Selected Text:</source>
        <translation>მონიშნული ტექსტი:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="208"/>
        <source>Tooltip Text:</source>
        <translation>მინიშნების ტექსტი:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="222"/>
        <source>Visited Link:</source>
        <translation>ნანახი ბმული:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="254"/>
        <source>&amp;Save Palette</source>
        <translation>პალიტრის &amp;შენახვა</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="261"/>
        <source>&amp;Load Palette</source>
        <translation>&amp;პალიტრის ჩატვირთვა</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="281"/>
        <source>&amp;Default Palette</source>
        <translation>&amp;ნაგულისხმევი პალიტრა</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="296"/>
        <location filename="../styleconfig.ui" line="306"/>
        <location filename="../styleconfig.ui" line="338"/>
        <location filename="../styleconfig.ui" line="348"/>
        <location filename="../styleconfig.ui" line="380"/>
        <source>May be overridden by Qt style or app</source>
        <translation>გადაიფარება Qt-ის სტილით ან აპით</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="299"/>
        <source>Toolbar button style:</source>
        <translation>ხელსაწყოების პანელის ღილაკის სტილი:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="310"/>
        <source>Only display the icon</source>
        <translation>მხოლოდ, ხატულის ჩვენება</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="315"/>
        <source>Only display the text</source>
        <translation>მხოლოდ ტექსტის ჩვენება</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="320"/>
        <source>The text appears beside the icon</source>
        <translation>ტექსტი ხატულის გვერდით გამოჩნდება</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="325"/>
        <source>The text appears under the icon</source>
        <translation>ხატულის ქვემოთ ტექსტი გამოჩნდება</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="330"/>
        <source>Default</source>
        <translation>ნაგულისხმევი</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="341"/>
        <source>Toolbar icon size:</source>
        <translation>ხელსაწყოების პანელის ხატულის ზომა:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="352"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="357"/>
        <source>22</source>
        <translation>22</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="362"/>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="367"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="372"/>
        <source>48</source>
        <translation>48</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="383"/>
        <source>Activate item on single click</source>
        <translation>ელემენტის გააქტიურება ერთი წკაპით</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Style:</source>
        <translation>Qt-ის სტილი:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <location filename="../styleconfig.cpp" line="340"/>
        <source>Save Palette</source>
        <translation>პალიტრის შენახვა</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <source>Palette name:</source>
        <translation>პალიტრის სახელი:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="341"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>პალიტრა ამ სახელით უკვე არსებობს.
გნებავთ, ჩაანაცვლოთ ის?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="484"/>
        <source>Remove Palettes</source>
        <translation>პალიტრების წაშლა</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="485"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>მართლა გნებავთ მონიშნული პალიტრების წაშლა?
ძირითადი პალიტრები, თუ არსებობს, არ წაიშლება.</translation>
    </message>
</context>
</TS>
